@@ -64,7 +64,7 @@ our @EXPORT = qw(
 	tokenizer_destroy	
 );
 
-our $VERSION = '0.4.0';
+our $VERSION = '0.4.1';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -109,29 +109,29 @@ Text::Tokenizer - Perl extension for tokenizing text(config) files
   use Text::Tokenizer ':all';
 
   #open file and set add it to tokenizer inputs
-  open(F_CONFIG, "input.conf");	
+  open(F_CONFIG, "input.conf") || die("failed to open input.conf");
   $tok_id	= tokenizer_new(F_CONFIG);
   tokenizer_options(TOK_OPT_NOUNESCAPE|TOK_OPT_PASSCOMMENT);
 
   while(1)
   {
 	($string, $tok_type, $line, $err, $errline)	= tokenizer_scan();
-	last if($tok == TOK_ERROR || $tok == TOK_EOF);
+	last if($tok_type == TOK_ERROR || $tok_type == TOK_EOF);
 
-	if($tok == TOK_TEXT)		{ 	}
-	elsif($tok == TOK_BLANK)	{ 	}
-	elsif($tok == TOK_DQUOTE)	{ $str	= "\"$str\"";	}
-	elsif($tok == TOK_SQUOTE)	{ $str	= "\'$str\'";	}
-	elsif($tok == TOK_SIQUOTE)	{ $str	= "\`$str\'";	}
-	elsif($tok == TOK_IQUOTE)	{ $str	= "\`$str\`";	}
-	elsif($tok == TOK_EOL)		{	}
-	elsif($tok == TOK_COMMENT)	{	}
-	elsif($tok == TOK_UNDEF)
-		{ last;		}
+	if($tok_type == TOK_TEXT)	{ 	}
+	elsif($tok_type == TOK_BLANK)	{ 	}
+	elsif($tok_type == TOK_DQUOTE)	{ $string	= "\"$str\"";	}
+	elsif($tok_type == TOK_SQUOTE)	{ $string	= "\'$str\'";	}
+	elsif($tok_type == TOK_SIQUOTE)	{ $string	= "\`$str\'";	}
+	elsif($tok_type == TOK_IQUOTE)	{ $string	= "\`$str\`";	}
+	elsif($tok_type == TOK_EOL)	{ $string	= "\n";		}
+	elsif($tok_type == TOK_COMMENT)	{	}
+	elsif($tok_type == TOK_UNDEF)
+		{ last;	}
 	else	{ last;	};
-	print $str;
+	print $string;
   }
-  tokenizer_delete($tokid);
+  tokenizer_delete($tok_id);
 
 
 =head1 DESCRIPTION
@@ -348,7 +348,7 @@ This tokenizer is based on code generated by B<flex> - fast lexical analyzer gen
 
 =head1 AUTHOR
 
-Samuel Behan, E<lt>samkob(at)gmail.comE<gt>
+Samuel Behan, E<lt>_samkob_(a)_gmail_._com_E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
